@@ -2,8 +2,8 @@
 
 # infra
 from .interface import AsyncRunnable, LazyLoadable
-from .types import (MessageTypes, ChannelTypes, ChannelPrivacyTypes, EventTypes, GuildMuteTypes, SlowModeTypes,
-                    RoleTypes, SoftwareTypes)
+from ._types import (MessageTypes, ChannelTypes, ChannelPrivacyTypes, EventTypes, GuildMuteTypes, SlowModeTypes,
+                     RoleTypes, SoftwareTypes)
 from .cert import Cert
 from .receiver import Receiver, WebhookReceiver, WebsocketReceiver
 from .requester import HTTPRequester
